@@ -4,8 +4,9 @@ utils::globalVariables(c("vl", "time", "id",
                          "calculation", "model", "Model",
                          "Included",
                          "Param", "param", "estimate",
-                         "A", "B", "delta", "gamma", "Bhat", "gammahat",
+                         "A", "B", "delta", "gamma", "Bhat", "gammahat", "omega",
                          "ShortLifespan", "LongLifespan", "SingleLifespan",
+                         "LongLifespanNonProductive", "ShortLifespanProductive", "ShortLifespanNonProductive",
                          "Median", "SD",
                          "TTS", "ART", "fit",
                          "lowerCI", "upperCI", "CIrange", "relativerange",
